@@ -236,7 +236,11 @@ setMethod("import", "BEDFile",
             file <- con
             con <- queryForConnection(con, which)
             if (attr(con, "usedWhich"))
-              which <- NULL
+                which <- NULL
+            if (is(genome, "Seqinfo")) {
+                seqinfo <- genome
+                genome <- NA_character_
+            }
             if (is.null(seqinfo))
               seqinfo <- attr(con, "seqinfo")
             ## check for a track line
@@ -500,6 +504,7 @@ setMethod("import", "BEDPEFile",
               df <- mcols(gr)
               mcols(gr) <- NULL
               df$strand2[is.na(df$strand2)] <- "*"
+              seqlevels(gr) <- union(seqlevels(gr), unique(df$chrom2))
               gr2 <- with(df, GRanges(chrom2, IRanges(start2+1L, end2),
                                       strand2, seqinfo=seqinfo(gr)))
               df <- subset(df, select=-(chrom2:end2))
@@ -589,15 +594,20 @@ setMethod("asBED", "GRangesList", function(x) {
   if (any(elementNROWS(x_range) != 1L))
     stop("Empty or multi-strand/seqname elements not supported by BED")
   gr <- unlist(x_range, use.names=FALSE)
-  values(gr) <- values(x)
-  values(gr)$name <- names(x)
+  mcols(gr) <- mcols(x)
+  mcols(gr)$name <- names(x)
   x_ranges <- ranges(unlist(x, use.names=FALSE))
-  ord_start <- order(start(x_ranges))
+  ord_start <- order(togroup(PartitioningByEnd(x)), start(x_ranges))
   x_ranges <- shift(x_ranges, 1L - rep(start(gr), elementNROWS(x)))[ord_start]
-  values(gr)$blocks <- split(x_ranges, togroup(x)[ord_start])
+  mcols(gr)$blocks <- relist(x_ranges, x)
   gr
 })
 
+setMethod("asBED", "GAlignments", function(x) {
+    x <- grglist(x)
+    callGeneric()
+})
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Utilities
 ###
@@ -607,11 +617,16 @@ setGeneric("blocks", function(x, ...) standardGeneric("blocks"))
 setMethod("blocks", "GenomicRanges",
           function(x)
           {
-            block_counts <- elementNROWS(values(x)$blocks)
+            if (is.null(mcols(x)$blocks)) {
+                return(as(x, "GRangesList"))
+            }
+            block_counts <- elementNROWS(mcols(x)$blocks)
             gr <- GRanges(rep(seqnames(x), block_counts),
-                          shift(unlist(values(x)$blocks, use.names = FALSE),
+                          shift(unlist(mcols(x)$blocks, use.names = FALSE),
                                 rep(start(x), block_counts) - 1L),
                           rep(strand(x), block_counts))
             seqinfo(gr) <- seqinfo(x)
-            split(gr, togroup(values(x)$blocks))
+            ans <- relist(gr, mcols(x)$blocks)
+            mcols(ans) <- subset(mcols(x), select=-blocks)
+            ans
           })
