@@ -14,6 +14,10 @@
 setClass("RTLFile", representation(resource = "characterORconnection"),
          contains = "VIRTUAL")
 
+setClass("RTLFileList",
+         prototype = prototype(elementType = "RTLFile"),
+         contains = "SimpleList")
+
 resource <- function(x) x@resource
 
 connection <- function(x, open = "") {
@@ -70,7 +74,7 @@ FileForFormat <- function(path, format = file_ext(path)) {
   fileClassName <- fileClassNames[fileClassIndex]
   fileClass <- getClass(fileClassName)
   pkg <- packageSlot(fileClass)
-  if (is.null(pkg))
+  if (is.null(pkg) || identical(pkg, ".GlobalEnv"))
     ns <- topenv()
   else ns <- getNamespace(pkg[1])
   constructorName <- fileClassName
@@ -83,6 +87,8 @@ FileForFormat <- function(path, format = file_ext(path)) {
   get(constructorName, ns)(path)
 }
 
+setMethod("as.character", "RTLFile", function(x) path(x))
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Export
 ###
@@ -168,9 +174,7 @@ setMethod("import", c(con = "missing", text = "character"),
 setGeneric("bestFileFormat",
            function(x, dest, ...) standardGeneric("bestFileFormat"))
 
-setClassUnion("RangedDataORGenomicRanges", c("RangedData", "GenomicRanges"))
-
-setMethod("bestFileFormat", c("RangedDataORGenomicRanges", "ANY"),
+setMethod("bestFileFormat", c("GenomicRanges", "ANY"),
           function(x, dest) {
             ## have numbers on a single strand, use BigWig
             if (is.numeric(score(x)) && length(unique(strand(x))) == 1L)
