@@ -13,10 +13,7 @@ setMethod("initialize", "UCSCSession",
           {
             .Object@url <- url
             .Object@views <- new.env()
-            gwURL <- ucscURL(.Object, "gateway")
-            if (force) {
-                gwURL <- paste0(gwURL, '?redirect="manual"')
-            }
+            gwURL <- ucscURL(.Object, "gateway", force=force)
             gw <- httpGet(gwURL, cookiefile = tempfile(), header = TRUE,
                           .parse=FALSE, ...)
             if (grepl("redirectTd", gw)) {
@@ -411,14 +408,14 @@ setMethod("ucscSchemaDescription", "UCSCTableQuery", function(object)
       expr <- sprintf("tr/td[%d]", ind)
       children <- sapply(getNodeSet(tableNode, expr), xmlChildren)
       col <- rep(NA, length(children))
-      col[elementLengths(children) > 0] <-
+      col[elementNROWS(children) > 0] <-
         alphaNum(sapply(unlist(children), xmlValue))
       col
     }
     columnNames <- sapply(getNodeSet(tableNode, "tr[1]/th//text()"), xmlValue)
     columns <- lapply(seq_along(columnNames), getColumn)
     names(columns) <- columnNames
-    columns <- columns[elementLengths(columns) > 0]
+    columns <- columns[elementNROWS(columns) > 0]
     DataFrame(columns)
   }
   doc <- ucscTableGet(object, hgta_doSchema = "describe table schema")
@@ -644,7 +641,7 @@ setMethod("browserView", "UCSCSession",
             form <- list()
             if (!missing(range)) {
               if (is(range, "RangesList"))
-                range <- range[elementLengths(range) > 0L]
+                range <- range[elementNROWS(range) > 0L]
               if (length(range) > 1) {
                 ranges <- range
                 views <- vector("list", length(ranges))
@@ -1150,26 +1147,6 @@ setAs("UCSCData", "GRanges", function(from) {
   gr
 })
 
-setAs("RangedData", "UCSCData", function(from) {
-  line <- metadata(ranges(from))$trackLine
-  if (is.null(line)) {
-    if (is.numeric(score(from))) { # have numbers, let's plot them
-      type <- chooseGraphType(from)
-      line <- new("GraphTrackLine", type = type)
-    } else {
-      line <- new("BasicTrackLine")
-      db <- unique(genome(from))
-      if (length(db) == 1 && !is.na(db))
-        line@db <- db
-    }
-  }
-  new("UCSCData", as(from, "GRanges"), trackLine = line)
-})
-
-setAs("UCSCData", "RangedData", function(from) {
-  as(as(from, "GRanges"), "RangedData")
-})
-
 splitUCSCData <- function(x, f, drop=FALSE, ...) {
   GenomicRangesList(
     lapply(split(seq_along(x), f, drop=drop, ...),
@@ -1421,17 +1398,7 @@ setMethod("import", "UCSCFile",
               names(tsets) <- trackNames
             if (drop && length(tsets) == 1)
               return(tsets[[1]])
-            ans <- do.call(RangedDataList, lapply(tsets, as, "RangedData"))
-            GenomicRangesList(
-                       lapply(ans,
-                         function(rd) {
-                           line <- metadata(ranges(rd))$trackLine
-                           if (is.null(line))
-                             Class <- "GRanges"
-                           else
-                             Class <- "UCSCData"
-                           as(rd, Class)
-                         }))
+            GenomicRangesList(tsets)
           })
 
 
@@ -1724,12 +1691,15 @@ ucscURLTable <- c(gateway = "hgGateway", tracks = "hgTracks",
                   cart = "cartDump")
 
 ucscURL <-
-  function(object, key)
+  function(object, key, force=TRUE)
   {
     path <- ucscURLTable[key]
     if (is.na(path))
-      stop("Key '", key, "' does not match a known URL")
-    else paste(object@url, path, sep="")
+        stop("Key '", key, "' does not match a known URL")
+    if (force && key == "gateway") {
+        path <- paste0(path, '?redirect="manual"')
+    }
+    paste(object@url, path, sep="")
   }
 
 # convenience wrappers for _initialized_ sessions
