@@ -148,14 +148,13 @@ test_gff <- function() {
   test <- import(test_gff3_out)
   checkIdentical(test, correct_hg19)
 
-  ## TEST: colnames empty, colnames := "geneName", colnames := "strand"
+  ## TEST: colnames empty, colnames := "geneName"
   test <- import(test_gff3, colnames = character())
   target <- correct_gff3[,character()]
   checkIdentical(target, test)
   test <- import(test_gff3, colnames = "geneName")
   target <- correct_gff3[,"geneName"]
   checkIdentical(target, test)
-  checkException(import(test_gff3, colnames = "strand"))
 
   ## TEST: import from connection
   test_gff_con <- file(test_gff_out)
@@ -189,7 +188,7 @@ test_gff <- function() {
   checkIdentical(target, test)
 
   ## TEST: 'which'
-  which <- RangesList(chr10 = IRanges(90000, 93000))
+  which <- GRanges("chr10:90000-93000")
   which_target <- subsetByOverlaps(correct_gff3, which)
   test <- import(test_gff3, which = which)
   checkIdentical(which_target, test)
